@@ -1,8 +1,15 @@
-
+/*$Id: str_search.h,v 1.2 2006/10/06 19:31:40 jwrobel Exp $*/
 /*
  *  Copyright (C) 2006 Jan Wrobel
  *  Copyright (C) 2005 Sourcefire,Inc.
  */
+
+/*
+  API to access multi-pattern search engine.
+  Firekeeper uses now only one search algorithm (see acsmx.cpp).
+  TODO: make it more C++ish
+ */
+
 #ifndef __STR_SEARCH_H__
 #define __STR_SEARCH_H__
 
@@ -12,9 +19,12 @@ int  SearchReInit(unsigned int i);
 void SearchFree();
 void SearchAdd(unsigned int mpse_id, unsigned char *pat, unsigned int pat_len, 
 	       int nocase, int id);
+
 typedef int (*MatchFunction)(void *, int, void *);
-int  SearchFindString(unsigned int mpse_id, unsigned char *str, unsigned int str_len, 
-		      int (*Match) (void *, int, void *), void *ctx);
+
+int  SearchFindString(unsigned int mpse_id, unsigned char *str, 
+		      unsigned int str_len, 
+		      MatchFunction, void *ctx);
 
 typedef struct _search_api
 {
@@ -24,9 +34,11 @@ typedef struct _search_api
 
 	void (*search_free)();
 
-	void (*search_add)(unsigned int, unsigned char *, unsigned int, int, void *);
+	void (*search_add)(unsigned int, unsigned char *, 
+			   unsigned int, int, void *);
 
-	int (*search_find)(unsigned int, unsigned char *, unsigned int, MatchFunction, void *); 
+	int (*search_find)(unsigned int, unsigned char *, 
+			   unsigned int, MatchFunction, void *); 
 } SearchAPI;
 
 extern SearchAPI *searchAPI;
